Index: src/api-natives.cc |
diff --git a/src/api-natives.cc b/src/api-natives.cc |
index 5993859710a5e1d4063b6900c5af6d1168e82a97..48c1a87255e19829a3197643ada3be0baabb08bc 100644 |
--- a/src/api-natives.cc |
+++ b/src/api-natives.cc |
@@ -491,9 +491,9 @@ Handle<JSFunction> ApiNatives::CreateApiFunction( |
map->set_has_indexed_interceptor(); |
} |
// Set instance call-as-function information in the map. |
if (!obj->instance_call_handler()->IsUndefined()) { |
- map->set_has_instance_call_handler(); |
+ map->set_is_callable(); |
} |
// Recursively copy parent instance templates' accessors, |
@@ -491,9 +491,9 @@ Handle<JSFunction> ApiNatives::CreateApiFunction( |
map->set_has_indexed_interceptor(); |
} |
- // Set instance call-as-function information in the map. |
+ // Mark instance as callable in the map. |
if (!obj->instance_call_handler()->IsUndefined()) { |